.TH sam n "20 Mar 2000" Linux "Linux Programmer's Manual"
.SH NAME
sam \- sam9407 device driver interface

.SH SYNOPSIS
\fBsam\fR \fIsubCommand\fR ?\fIarg arg ...\fR?

.SH DESCRIPTION
This command provides an interface to the sam9407 mixer.
Legal sub-commands are:

.SS "sam open \fR?\fB-device \fIdeviceName\fR? ?\fB-card \fIcardNr\fR? ?\fB-noEvents\fR? "
This will open a channel to the mixer device as defined and return a handle to it.
This channel can be used as an identifier to many sub-commands by passing
it as an argument to the \fB-channel\fR option.
.TP
.B "-device \fIdeviceName\fB"
Use this option to open a sam9407 device, which is accessed through a non-standard pathname.
Usually the module will try to open the device as \fB/dev/sam9407/card\fR[0-9]\fB/mixer\fR
(using \fBdevfs\fR) or \fB/dev/sam\fR[0-9]\fB_mixer\fR.
.TP
.B "-card \fIcardNr\fB"
Open a mixer channel on the card number given. Counting starts with \fB0\fR.
.TP
.B "-noEvents"
No events will be reported, even if an event handler has been registered.

.SS "sam close \fIchannel\fR"
Close an open mixer channel.

.SS "sam file \fR?\fB-channel \fIchannel\fR?"
Return the file descriptor number of the mixer channel identifier as returned
by the \fBopen\fR sub-command.

.SS "sam event \fR?\fB-channel \fIchannel\fR? \fIhandler\fR"
Register an \fIhandler\fR that should be called whenever an event happened on the sam9407 device.
The handler will be passed the channel identifier and a list of events.
Possible events are:
.TP
.B "firmware"
A new firmware has been loaded.

The user shall call the \fBapi_info\fR function to ensure
the module's state information is in sync with the firmware
currently loaded.
.TP
.B "sbank"
An element in the soundbank changed.
.TP
.B "channel_owner"
A process opened or closed an audio streaming channel.
.TP
.B "mixer \fIctrlName addr\fB"
The mixer control \fIctrlName\fR with sub address \fBaddr\fR has changed.
.TP
.B "audio \fIchannel ctrlName addr\fB"
The audio control at the given \fIchannel\fR named \fIctrlName\fR with
sub address \fBaddr\fR has changed.

.SS "sam api_info \fR?\fB-channel \fIchannel\fR?"
Query the API information from the driver. The result will be a list
of \fIkey\fR \fIvalue\fR pairs, with they following keywords known:
.TP
.B "version"
The mixer API version of the installed driver.
.TP
.B "apiClass"
The API class of the firmware currently loaded.

.PP
As a side effect, the module's internal state information
will be updated, if this is necessary due to a firmware change.

.SS "sam sync_join \fR?\fB-channel \fIchannel\fR? ?\fIsync_group\fR?"
Join or create a sync playback group. If the optional sync_group parameter
is negative, a new playback group will be created.
The result will be a handle for this playback group.

.SS "sam sync_leave \fR?\fB-channel \fIchannel\fR?"
Leave the currently joined sync playback group again.

.SS "sam sync_info \fR?\fB-channel \fIchannel\fR?"
Query the currently joined sync playback group.
If no playback group has been joined, the returned handle
will be negative.

.SS "sam driver_info \fR?\fB-channel \fIchannel\fR?"
Query the driver information. The result will be a list
of \fIkey\fR \fIvalue\fR pairs, with they following keywords known:
.TP
.B "version"
The driver's version number.
.TP
.B "hardware"
An identifier for the card type.
.TP
.B "firmware"
An identifier for the firmware type being loaded.
.TP
.B "haveAudio"
True, if the firmware supports streaming audio.
.TP
.B "haveMidi"
True, if the firmware supports midi and sequencer functions.
.TP
.B "memTotal"
The total amount of memory installed on the card in words (2 bytes).
.TP
.B "memFree"
The amount of available memory on the card in words (2 byte).
.TP
.B "memSBanks"
The amount of memory used by sound banks in words (2 bytes).
.TP
.B "memAudio"
The amount of memory allocaed by streaming audio channels in words (2 bytes).
.TP
.B "playChannelsUsed"
How many streaming audio playback channels are currently open.
.TP
.B "playChannelsTotal"
How many streaming audio playback channels are available in total.
.TP
.B "playChannelsUsed"
How many streaming audio recording channels are currently open.
.TP
.B "playChannelsTotal"
How many streaming audio recording channels are available in total.

.SS "sam hw_hints_get \fR?\fB-channel \fIchannel\fR?"
Query the driver's hardware hints. The result will be a list
of \fIkey\fR \fIvalue\fR pairs. Please refer to \fBhw_hints_set\fR
for a description of possible keywords.

.SS "sam hw_hints_set \fR?\fB-channel \fIchannel\fR? ?\fB-cardMem \fImem\fR?"
Gives some hardware hints to the driver, that could be any of:
.TP
.B "-cardMem \fImem\fB"
The amount of memory installed on the card in words (2 bytes).
\fBcardMem\fR is only used if the uploaded firmware cannot detect
the amount of memory installed, in which case an autprobe algorithm
would try to detect the amount of memory on the card. If this hint
is set however, no autoprobing will take place.
.PP
Using this function requires root priviledge.

.SS "sam firmware_load \fR?\fB-channel \fIchannel\fR? ?\fB--\fR? \fIfileName\fB"
Upload and initialize the sam9407 firmware found in \fIfileName\fR.
Using this function requires root priviledge.

.SS "sam mixer_known \fR?\fB-channel \fIchannel\fR?"
Return all mixer control names known to the Tcl module.

.SS "sam mixer_get \fR?\fB-channel \fIchannel\fR? ?\fB--\fR? \fIcontrol control ...\fB"
For each \fIcontrol\fR, which consists of the control name and optionally
an address, query the current mixer value and return a list of:
.sp
.nf
\fB{\fIcontrolName addr value\fB}\fR
.fi
.sp

.SS "sam mixer_set \fR?\fB-channel \fIchannel\fR? ?\fB--\fR? \fIcontrol control ...\fB"
Set the mixer values passed as a list of
.sp
.nf
\fB{\fIcontrolName addr value\fB}\fR
.fi
.sp

.SS "sam mixer_info \fR?\fB-channel \fIchannel\fR?  ?\fB--\fR? \fIcontrolName controlName ...\fB"
For each \fIcontrolName\fR,
return if the control is supported as a list of:
.sp
.nf
\fB{\fIcontrolName supported\fB}\fR
.fi
.sp

.SS "sam mixer_audio_known \fR?\fB-channel \fIchannel\fR?"
Return all audio control names known to the Tcl module.

.SS "sam mixer_audio_get \fR?\fB-channel \fIchannel\fR? -\fBaudio_channel \fIaudioChannel\fR ?\fB--\fR? \fIcontrol control ...\fB"
For each \fIcontrol\fR, which consists of the control name and optionally
an address, query the current audio control value for audio channel \fIaudioChannel\fR
and return a list of:
.sp
.nf
\fB{\fIcontrolName addr isConfigured value\fB}\fR
.fi
.sp
If the control has a temporary lifetime and will cease to exist whenever
the audio channel is closed again, \fIisConfigured\fR indicates if that control has
been configured. For all other controls \fIisConfigured\fR will always be true.

.SS "sam mixer_audio_set \fR?\fB-channel \fIchannel\fR? -\fBaudio_channel \fIaudioChannel\fR ?\fB--\fR? \fIcontrol control ...\fB"
Set at audio channel \fIaudioChannel\fR the control values passed as a list of
.sp
.nf
\fB{\fIcontrolName addr value\fB}\fR
.fi
.sp

.SS "sam mixer_audio_info \fR?\fB-channel \fIchannel\fR? -\fBaudio_channel \fIaudioChannel\fR ?\fB--\fR? \fIcontrolName controlName ...\fB"
For each \fIcontrolName\fR,
return if the control is supported at audio channel \fIaudioChannel\fR as a list of:
.sp
.nf
\fB{\fIcontrolName supported\fB}\fR
.fi
.sp

.SS "sam channel_owner_info \fR?\fB-channel \fIchannel\fR?"
Retrieve and store the process id's of the owning processes for all known channels.
If the value is zero, the corresponding audio channel is currently not in use.

.SS "sam bank_load \fR?\fB-channel \fIchannel\fR? ?\fB--\fR? \fIid fileName\fB"
Upload the soundbank stored in \fIfileName\fR to the soundbank slot \fIid\fR.

.SS "sam bank_unload \fR?\fB-channel \fIchannel\fR? ?\fB--\fR? \fIid\fB"
Unload the soundbank stored at slot \fIid\fR.

.SS "sam bank_prio_chg \fR?\fB-channel \fIchannel\fR? ?\fB--\fR? \fIid priority\fB"
Change the priority level of the soundbank stored at slot \fIid\fR to \fIpriority\fR.

.SS "sam bank_info \fR?\fB-channel \fIchannel\fR?"
Query the all soundbanks. The result will be a list
of \fIkey\fR \fIvalue\fR pairs, with they following keywords known:
.TP
.B "name"
The name of the soundbank
.TP
.B "priority"
The priority level of the soundbank

.SS "sam peak_meter_info \fR?\fB-channel \fIchannel\fR?"
Return a list of the current peak meter values known to the firmware.

.SH AUTHOR
Gerd Rausch <gerd@meshed.net>
